@@ -1,5 +1,5 @@
 def start():
-    print("import successful")
+    print("import successful v1.2")
 
 import yagmail
 import time
@@ -36,4 +36,19 @@ def time_counter(user = '',  password='',to = [''],\
             return ret
         return inner
 
-    return decorator
\ No newline at end of file
+    return decorator
+
+
+def Esender(user = '',  password='',to = [''],\
+                 subject = 'No subject',content = None, attachment = None):
+    '''
+    user(str)
+    password(str)
+    to(str)(list(str))
+    subject(str)
+    content(str)(list(str))
+    attachment(str)(list(str))
+    '''
+    yag = yagmail.SMTP(user=user, password=password, host='smtp.163.com', encoding='GBK')
+    yag.send(to, subject,content,attachment)
+    yag.close()
